@@ -39,12 +39,10 @@
 # coding: utf-8
 
 import logging
-from os.path import exists, join, isdir
-from os import getenv
-import subprocess
-from sys import platform
+import time
+import threading
+import sys
 from pygccxml import declarations, parser
-from pygccxml.utils import xml_generator
 from pyplusplus import module_builder, messages
 from pyplusplus.module_builder import call_policies
 from pyplusplus.decl_wrappers import print_declarations
@@ -108,6 +106,17 @@ def returns_reference(decl):
     c = decl.return_type.decl_string[-1]
     return c=='&' or c=='*'
 
+class Heartbeat(object):
+    def __init__(self, delay):
+        self.start = time.time()
+        self.delay = delay
+    def __call__(self):
+        while True:
+            time.sleep(self.delay)
+            t = time.time()
+            print('still alive after %g seconds!' % (t - self.start))
+            sys.stdout.flush()
+
 class code_generator_t(object):
     """The base class code generator."""
 
@@ -115,12 +124,19 @@ class code_generator_t(object):
         """Constructor.
         @name name of the python module
         @dep name of another module this module depends on"""
-        module_builder.set_logger_level( logging.INFO )
-        xml_generator_config = parser.load_xml_generator_configuration("/Users/mmoll/build/omplapp/Release/castxml.cfg")
+        # create a separate thread that prints out a message every 60 seconds
+        # to let build bots know the build is not stuck.
+        self.heartbeat = threading.Thread(target = Heartbeat(60))
+        self.heartbeat.daemon = True
+        self.heartbeat.start()
+        xml_generator_config = parser.load_xml_generator_configuration("/Users/mmoll/build/ompl/Release/castxml.cfg")
         self.mb = module_builder.module_builder_t(
             files = [ 'bindings/' + name + '.h' ],
-            cache = '/Users/mmoll/build/omplapp/Release/pyplusplus_'+name+'.cache',
+            # cache is not used with compilation_mode = parser.COMPILATION_MODE.ALL_AT_ONCE
+            #cache = '/Users/mmoll/build/ompl/Release/pyplusplus_'+name+'.cache',
             xml_generator_config = xml_generator_config,
+            start_with_declarations = ['ompl::' + name],
+            compilation_mode = parser.COMPILATION_MODE.ALL_AT_ONCE,
             indexing_suite_version = indexing_suite_version )
         self.replacement = {} if replacement_dict==None else replacement_dict
         self.mb.classes().always_expose_using_scope = True
@@ -154,7 +170,10 @@ class code_generator_t(object):
 
     def filter_declarations(self):
         """Remove some classes and functions from the std namespace"""
-        self.std_ns.class_('ios_base').exclude()
+        try:
+            self.std_ns.class_('ios_base').exclude()
+        except:
+            pass
         self.std_ns.free_functions().exclude()
         self.std_ns.operators().exclude()
 
