@@ -32,7 +32,7 @@
 *  POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************/
 
-/* Author: Ioan Sucan */
+/* Author: Ioan Sucan, Ryan Luna */
 
 #include "ompl/geometric/PathSimplifier.h"
 #include "ompl/tools/config/MagicConstants.h"
@@ -41,6 +41,19 @@
 #include <cstdlib>
 #include <cmath>
 #include <map>
+#include <utility>
+
+ompl::geometric::PathSimplifier::PathSimplifier(base::SpaceInformationPtr si, const base::GoalPtr &goal)
+  : si_(std::move(si)), freeStates_(true)
+{
+    if (goal)
+    {
+        gsr_ = std::dynamic_pointer_cast<base::GoalSampleableRegion>(goal);
+        if (!gsr_)
+            OMPL_WARN("%s: Goal could not be cast to GoalSampleableRegion.  Goal simplification will not be performed.",
+                      __FUNCTION__);
+    }
+}
 
 bool ompl::geometric::PathSimplifier::freeStates() const
 {
@@ -59,12 +72,12 @@ void ompl::geometric::PathSimplifier::smoothBSpline(PathGeometric &path, unsigne
         return;
 
     const base::SpaceInformationPtr &si = path.getSpaceInformation();
-    std::vector<base::State*> &states = path.getStates();
+    std::vector<base::State *> &states = path.getStates();
 
     base::State *temp1 = si->allocState();
     base::State *temp2 = si->allocState();
 
-    for (unsigned int s = 0 ; s < maxSteps ; ++s)
+    for (unsigned int s = 0; s < maxSteps; ++s)
     {
         path.subdivide();
 
@@ -97,7 +110,8 @@ void ompl::geometric::PathSimplifier::smoothBSpline(PathGeometric &path, unsigne
     si->freeState(temp2);
 }
 
-bool ompl::geometric::PathSimplifier::reduceVertices(PathGeometric &path, unsigned int maxSteps, unsigned int maxEmptySteps, double rangeRatio)
+bool ompl::geometric::PathSimplifier::reduceVertices(PathGeometric &path, unsigned int maxSteps,
+                                                     unsigned int maxEmptySteps, double rangeRatio)
 {
     if (path.getStateCount() < 3)
         return false;
@@ -111,24 +125,24 @@ bool ompl::geometric::PathSimplifier::reduceVertices(PathGeometric &path, unsign
     bool result = false;
     unsigned int nochange = 0;
     const base::SpaceInformationPtr &si = path.getSpaceInformation();
-    std::vector<base::State*> &states = path.getStates();
+    std::vector<base::State *> &states = path.getStates();
 
     if (si->checkMotion(states.front(), states.back()))
     {
         if (freeStates_)
-            for (std::size_t i = 2 ; i < states.size() ; ++i)
-                si->freeState(states[i-1]);
-        std::vector<base::State*> newStates(2);
+            for (std::size_t i = 2; i < states.size(); ++i)
+                si->freeState(states[i - 1]);
+        std::vector<base::State *> newStates(2);
         newStates[0] = states.front();
         newStates[1] = states.back();
         states.swap(newStates);
         result = true;
     }
     else
-        for (unsigned int i = 0 ; i < maxSteps && nochange < maxEmptySteps ; ++i, ++nochange)
+        for (unsigned int i = 0; i < maxSteps && nochange < maxEmptySteps; ++i, ++nochange)
         {
             int count = states.size();
-            int maxN  = count - 1;
+            int maxN = count - 1;
             int range = 1 + (int)(floor(0.5 + (double)count * rangeRatio));
 
             int p1 = rng_.uniformInt(0, maxN);
@@ -137,11 +151,10 @@ bool ompl::geometric::PathSimplifier::reduceVertices(PathGeometric &path, unsign
             {
                 if (p1 < maxN - 1)
                     p2 = p1 + 2;
+                else if (p1 > 1)
+                    p2 = p1 - 2;
                 else
-                    if (p1 > 1)
-                        p2 = p1 - 2;
-                    else
-                        continue;
+                    continue;
             }
 
             if (p1 > p2)
@@ -150,7 +163,7 @@ bool ompl::geometric::PathSimplifier::reduceVertices(PathGeometric &path, unsign
             if (si->checkMotion(states[p1], states[p2]))
             {
                 if (freeStates_)
-                    for (int j = p1 + 1 ; j < p2 ; ++j)
+                    for (int j = p1 + 1; j < p2; ++j)
                         si->freeState(states[j]);
                 states.erase(states.begin() + p1 + 1, states.begin() + p2);
                 nochange = 0;
@@ -160,7 +173,8 @@ bool ompl::geometric::PathSimplifier::reduceVertices(PathGeometric &path, unsign
     return result;
 }
 
-bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned int maxSteps, unsigned int maxEmptySteps, double rangeRatio, double snapToVertex)
+bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned int maxSteps,
+                                                   unsigned int maxEmptySteps, double rangeRatio, double snapToVertex)
 {
     if (path.getStateCount() < 3)
         return false;
@@ -172,59 +186,71 @@ bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned
         maxEmptySteps = path.getStateCount();
 
     const base::SpaceInformationPtr &si = path.getSpaceInformation();
-    std::vector<base::State*> &states = path.getStates();
+    std::vector<base::State *> &states = path.getStates();
 
+    // dists[i] contains the cumulative length of the path up to and including state i
     std::vector<double> dists(states.size(), 0.0);
-    for (unsigned int i = 1 ; i < dists.size() ; ++i)
-        dists[i] = dists[i - 1] + si->distance(states[i-1], states[i]);
+    for (unsigned int i = 1; i < dists.size(); ++i)
+        dists[i] = dists[i - 1] + si->distance(states[i - 1], states[i]);
+    // Sampled states closer than 'threshold' distance to any existing state in the path
+    // are snapped to the close state
     double threshold = dists.back() * snapToVertex;
+    // The range (distance) of a single connection that will be attempted
     double rd = rangeRatio * dists.back();
 
     base::State *temp0 = si->allocState();
     base::State *temp1 = si->allocState();
     bool result = false;
     unsigned int nochange = 0;
-    for (unsigned int i = 0 ; i < maxSteps && nochange < maxEmptySteps ; ++i, ++nochange)
+    // Attempt shortcutting maxSteps times or when no improvement is found after
+    // maxEmptySteps attempts, whichever comes first
+    for (unsigned int i = 0; i < maxSteps && nochange < maxEmptySteps; ++i, ++nochange)
     {
-        base::State *s0 = NULL;
+        // Sample a random point anywhere along the path
+        base::State *s0 = nullptr;
         int index0 = -1;
         double t0 = 0.0;
-        double p0 = rng_.uniformReal(0.0, dists.back());
-        std::vector<double>::iterator pit = std::lower_bound(dists.begin(), dists.end(), p0);
-        int pos0 = pit == dists.end() ? dists.size() - 1 : pit - dists.begin();
+        double p0 = rng_.uniformReal(0.0, dists.back());              // sample a random point (p0) along the path
+        auto pit = std::lower_bound(dists.begin(), dists.end(), p0);  // find the NEXT waypoint after the random point
+        int pos0 = pit == dists.end() ? dists.size() - 1 :
+                                        pit - dists.begin();  // get the index of the NEXT waypoint after the point
 
-        if (pos0 == 0 || dists[pos0] - p0 < threshold)
+        if (pos0 == 0 || dists[pos0] - p0 < threshold)  // snap to the NEXT waypoint
             index0 = pos0;
         else
         {
             while (pos0 > 0 && p0 < dists[pos0])
                 --pos0;
-            if (p0 - dists[pos0] < threshold)
+            if (p0 - dists[pos0] < threshold)  // snap to the PREVIOUS waypoint
                 index0 = pos0;
         }
 
-        base::State *s1 = NULL;
+        // Sample a random point within rd distance of the previously sampled point
+        base::State *s1 = nullptr;
         int index1 = -1;
         double t1 = 0.0;
-        double p1 = rng_.uniformReal(std::max(0.0, p0 - rd), std::min(p0 + rd, dists.back()));
-        pit = std::lower_bound(dists.begin(), dists.end(), p1);
-        int pos1 = pit == dists.end() ? dists.size() - 1 : pit - dists.begin();
+        double p1 = rng_.uniformReal(std::max(0.0, p0 - rd),
+                                     std::min(p0 + rd, dists.back()));  // sample a random point (p1) near p0
+        pit = std::lower_bound(dists.begin(), dists.end(), p1);         // find the NEXT waypoint after the random point
+        int pos1 = pit == dists.end() ? dists.size() - 1 :
+                                        pit - dists.begin();  // get the index of the NEXT waypoint after the point
 
-        if (pos1 == 0 || dists[pos1] - p1 < threshold)
+        if (pos1 == 0 || dists[pos1] - p1 < threshold)  // snap to the NEXT waypoint
             index1 = pos1;
         else
         {
             while (pos1 > 0 && p1 < dists[pos1])
                 --pos1;
-            if (p1 - dists[pos1] < threshold)
+            if (p1 - dists[pos1] < threshold)  // snap to the PREVIOUS waypoint
                 index1 = pos1;
         }
 
-        if (pos0 == pos1 || index0 == pos1 || index1 == pos0 ||
-            pos0 + 1 == index1 || pos1 + 1 == index0 ||
-            (index0 >=0 && index1 >= 0 && abs(index0 - index1) < 2))
+        // Don't waste time on points that are on the same path segment
+        if (pos0 == pos1 || index0 == pos1 || index1 == pos0 || pos0 + 1 == index1 || pos1 + 1 == index0 ||
+            (index0 >= 0 && index1 >= 0 && abs(index0 - index1) < 2))
             continue;
 
+        // Get the state pointer for p0
         if (index0 >= 0)
             s0 = states[index0];
         else
@@ -234,6 +260,7 @@ bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned
             s0 = temp0;
         }
 
+        // Get the state pointer for p1
         if (index1 >= 0)
             s1 = states[index1];
         else
@@ -243,6 +270,7 @@ bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned
             s1 = temp1;
         }
 
+        // Check for validity between s0 and s1
         if (si->checkMotion(s0, s1))
         {
             if (pos0 > pos1)
@@ -253,6 +281,7 @@ bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned
                 std::swap(t0, t1);
             }
 
+            // Modify the path with the new, shorter result
             if (index0 < 0 && index1 < 0)
             {
                 if (pos0 + 1 == pos1)
@@ -263,44 +292,41 @@ bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned
                 else
                 {
                     if (freeStates_)
-                        for (int j = pos0 + 2 ; j < pos1 ; ++j)
+                        for (int j = pos0 + 2; j < pos1; ++j)
                             si->freeState(states[j]);
                     si->copyState(states[pos0 + 1], s0);
                     si->copyState(states[pos1], s1);
                     states.erase(states.begin() + pos0 + 2, states.begin() + pos1);
                 }
             }
-            else
-                if (index0 >= 0 && index1 >= 0)
-                {
-                    if (freeStates_)
-                        for (int j = index0 + 1 ; j < index1 ; ++j)
-                            si->freeState(states[j]);
-                    states.erase(states.begin() + index0 + 1, states.begin() + index1);
-                }
-                else
-                    if (index0 < 0 && index1 >= 0)
-                    {
-                        if (freeStates_)
-                            for (int j = pos0 + 2 ; j < index1 ; ++j)
-                                si->freeState(states[j]);
-                        si->copyState(states[pos0 + 1], s0);
-                        states.erase(states.begin() + pos0 + 2, states.begin() + index1);
-                    }
-                    else
-                        if (index0 >= 0 && index1 < 0)
-                        {
-                            if (freeStates_)
-                                for (int j = index0 + 1 ; j < pos1 ; ++j)
-                                    si->freeState(states[j]);
-                            si->copyState(states[pos1], s1);
-                            states.erase(states.begin() + index0 + 1, states.begin() + pos1);
-                        }
+            else if (index0 >= 0 && index1 >= 0)
+            {
+                if (freeStates_)
+                    for (int j = index0 + 1; j < index1; ++j)
+                        si->freeState(states[j]);
+                states.erase(states.begin() + index0 + 1, states.begin() + index1);
+            }
+            else if (index0 < 0 && index1 >= 0)
+            {
+                if (freeStates_)
+                    for (int j = pos0 + 2; j < index1; ++j)
+                        si->freeState(states[j]);
+                si->copyState(states[pos0 + 1], s0);
+                states.erase(states.begin() + pos0 + 2, states.begin() + index1);
+            }
+            else if (index0 >= 0 && index1 < 0)
+            {
+                if (freeStates_)
+                    for (int j = index0 + 1; j < pos1; ++j)
+                        si->freeState(states[j]);
+                si->copyState(states[pos1], s1);
+                states.erase(states.begin() + index0 + 1, states.begin() + pos1);
+            }
 
             // fix the helper variables
             dists.resize(states.size(), 0.0);
-            for (unsigned int j = pos0 + 1 ; j < dists.size() ; ++j)
-                dists[j] = dists[j - 1] + si->distance(states[j-1], states[j]);
+            for (unsigned int j = pos0 + 1; j < dists.size(); ++j)
+                dists[j] = dists[j - 1] + si->distance(states[j - 1], states[j]);
             threshold = dists.back() * snapToVertex;
             rd = rangeRatio * dists.back();
             result = true;
@@ -313,7 +339,8 @@ bool ompl::geometric::PathSimplifier::shortcutPath(PathGeometric &path, unsigned
     return result;
 }
 
-bool ompl::geometric::PathSimplifier::collapseCloseVertices(PathGeometric &path, unsigned int maxSteps, unsigned int maxEmptySteps)
+bool ompl::geometric::PathSimplifier::collapseCloseVertices(PathGeometric &path, unsigned int maxSteps,
+                                                            unsigned int maxEmptySteps)
 {
     if (path.getStateCount() < 3)
         return false;
@@ -325,24 +352,24 @@ bool ompl::geometric::PathSimplifier::collapseCloseVertices(PathGeometric &path,
         maxEmptySteps = path.getStateCount();
 
     const base::SpaceInformationPtr &si = path.getSpaceInformation();
-    std::vector<base::State*> &states = path.getStates();
+    std::vector<base::State *> &states = path.getStates();
 
     // compute pair-wise distances in path (construct only half the matrix)
-    std::map<std::pair<const base::State*, const base::State*>, double> distances;
-    for (unsigned int i = 0 ; i < states.size() ; ++i)
-        for (unsigned int j = i + 2 ; j < states.size() ; ++j)
+    std::map<std::pair<const base::State *, const base::State *>, double> distances;
+    for (unsigned int i = 0; i < states.size(); ++i)
+        for (unsigned int j = i + 2; j < states.size(); ++j)
             distances[std::make_pair(states[i], states[j])] = si->distance(states[i], states[j]);
 
     bool result = false;
     unsigned int nochange = 0;
-    for (unsigned int s = 0 ; s < maxSteps && nochange < maxEmptySteps ; ++s, ++nochange)
+    for (unsigned int s = 0; s < maxSteps && nochange < maxEmptySteps; ++s, ++nochange)
     {
         // find closest pair of points
         double minDist = std::numeric_limits<double>::infinity();
         int p1 = -1;
         int p2 = -1;
-        for (unsigned int i = 0 ; i < states.size() ; ++i)
-            for (unsigned int j = i + 2 ; j < states.size() ; ++j)
+        for (unsigned int i = 0; i < states.size(); ++i)
+            for (unsigned int j = i + 2; j < states.size(); ++j)
             {
                 double d = distances[std::make_pair(states[i], states[j])];
                 if (d < minDist)
@@ -358,7 +385,7 @@ bool ompl::geometric::PathSimplifier::collapseCloseVertices(PathGeometric &path,
             if (si->checkMotion(states[p1], states[p2]))
             {
                 if (freeStates_)
-                    for (int i = p1 + 1 ; i < p2 ; ++i)
+                    for (int i = p1 + 1; i < p2; ++i)
                         si->freeState(states[i]);
                 states.erase(states.begin() + p1 + 1, states.begin() + p2);
                 result = true;
@@ -375,19 +402,8 @@ bool ompl::geometric::PathSimplifier::collapseCloseVertices(PathGeometric &path,
 
 void ompl::geometric::PathSimplifier::simplifyMax(PathGeometric &path)
 {
-    reduceVertices(path);
-    collapseCloseVertices(path);
-    // BSpline and checkAndRepair code only makes sense in a metric space.
-    if (si_->getStateSpace()->isMetricSpace())
-    {
-        smoothBSpline(path, 4, path.length()/100.0);
-        const std::pair<bool, bool> &p = path.checkAndRepair(magic::MAX_VALID_SAMPLE_ATTEMPTS);
-        if (!p.second)
-            OMPL_WARN("Solution path may slightly touch on an invalid region of the state space");
-        else
-            if (!p.first)
-                OMPL_DEBUG("The solution path was slightly touching on an invalid region of the state space, but it was successfully fixed.");
-    }
+    ompl::base::PlannerTerminationCondition neverTerminate = base::plannerNonTerminatingCondition();
+    simplify(path, neverTerminate);
 }
 
 void ompl::geometric::PathSimplifier::simplify(PathGeometric &path, double maxTime)
@@ -415,29 +431,173 @@ void ompl::geometric::PathSimplifier::simplify(PathGeometric &path, const base::
         tryMore = reduceVertices(path);
 
     // if the space is metric, we can do some additional smoothing
-    if(si_->getStateSpace()->isMetricSpace())
+    if (si_->getStateSpace()->isMetricSpace())
     {
-        // run a more complex short-cut algorithm : allow splitting path segments
-        if (ptc == false)
-            tryMore = shortcutPath(path);
-        else
-            tryMore = false;
+        bool tryMore = true;
+        unsigned int times = 0;
+        do
+        {
+            bool shortcut = shortcutPath(path);                           // split path segments, not just vertices
+            bool better_goal = gsr_ ? findBetterGoal(path, ptc) : false;  // Try to connect the path to a closer goal
 
-        // run the short-cut algorithm some more, if it makes a difference
-        times = 0;
-        while (tryMore && ptc == false && ++times <= 5)
-            tryMore = shortcutPath(path);
+            tryMore = shortcut || better_goal;
+        } while (ptc == false && tryMore && ++times <= 5);
 
         // smooth the path with BSpline interpolation
-        if(ptc == false)
-            smoothBSpline(path, 3, path.length()/100.0);
+        if (ptc == false)
+            smoothBSpline(path, 3, path.length() / 100.0);
 
         // we always run this if the metric-space algorithms were run.  In non-metric spaces this does not work.
         const std::pair<bool, bool> &p = path.checkAndRepair(magic::MAX_VALID_SAMPLE_ATTEMPTS);
         if (!p.second)
             OMPL_WARN("Solution path may slightly touch on an invalid region of the state space");
-        else
-            if (!p.first)
-                OMPL_DEBUG("The solution path was slightly touching on an invalid region of the state space, but it was successfully fixed.");
+        else if (!p.first)
+            OMPL_DEBUG("The solution path was slightly touching on an invalid region of the state space, but it was "
+                       "successfully fixed.");
     }
 }
+
+bool ompl::geometric::PathSimplifier::findBetterGoal(PathGeometric &path, double maxTime, unsigned int samplingAttempts,
+                                                     double rangeRatio, double snapToVertex)
+{
+    return findBetterGoal(path, base::timedPlannerTerminationCondition(maxTime), samplingAttempts, rangeRatio,
+                          snapToVertex);
+}
+
+bool ompl::geometric::PathSimplifier::findBetterGoal(PathGeometric &path, const base::PlannerTerminationCondition &ptc,
+                                                     unsigned int samplingAttempts, double rangeRatio,
+                                                     double snapToVertex)
+{
+    if (path.getStateCount() < 2)
+        return false;
+
+    if (!gsr_)
+    {
+        OMPL_WARN("%s: No goal sampleable object to sample a better goal from.", "PathSimplifier::findBetterGoal");
+        return false;
+    }
+
+    unsigned int maxGoals = std::min((unsigned)10, gsr_->maxSampleCount());  // the number of goals we will sample
+    unsigned int failedTries = 0;
+    bool betterGoal = false;
+
+    const base::StateSpacePtr &ss = si_->getStateSpace();
+    std::vector<base::State *> &states = path.getStates();
+
+    // dists[i] contains the cumulative length of the path up to and including state i
+    std::vector<double> dists(states.size(), 0.0);
+    for (unsigned int i = 1; i < dists.size(); ++i)
+        dists[i] = dists[i - 1] + si_->distance(states[i - 1], states[i]);
+
+    // Sampled states closer than 'threshold' distance to any existing state in the path
+    // are snapped to the close state
+    double threshold = dists.back() * snapToVertex;
+    // The range (distance) of a single connection that will be attempted
+    double rd = rangeRatio * dists.back();
+
+    base::State *temp = si_->allocState();
+    base::State *tempGoal = si_->allocState();
+
+    while (!ptc && failedTries++ < maxGoals && !betterGoal)
+    {
+        gsr_->sampleGoal(tempGoal);
+
+        // Goal state is not compatible with the start state
+        if (!gsr_->isStartGoalPairValid(path.getState(0), tempGoal))
+            continue;
+
+        unsigned int numSamples = 0;
+        while (!ptc && numSamples++ < samplingAttempts && !betterGoal)
+        {
+            // sample a state within rangeRatio
+            double t = rng_.uniformReal(std::max(dists.back() - rd, 0.0),
+                                        dists.back());  // Sample a random point within rd of the end of the path
+
+            auto end = std::lower_bound(dists.begin(), dists.end(), t);
+            auto start = end;
+            while (start != dists.begin() && *start >= t)
+                start -= 1;
+
+            unsigned int startIndex = start - dists.begin();
+            unsigned int endIndex = end - dists.begin();
+
+            // Snap the random point to the nearest vertex, if within the threshold
+            if (t - (*start) < threshold)  // snap to the starting waypoint
+                endIndex = startIndex;
+            if ((*end) - t < threshold)  // snap to the ending waypoint
+                startIndex = endIndex;
+
+            // Compute the state value and the accumulated cost up to that state
+            double costToCome = dists[startIndex];
+            base::State *state;
+            if (startIndex == endIndex)
+            {
+                state = states[startIndex];
+            }
+            else
+            {
+                double tSeg = (t - (*start)) / (*end - *start);
+                ss->interpolate(states[startIndex], states[endIndex], tSeg, temp);
+                state = temp;
+
+                costToCome += si_->distance(states[startIndex], state);
+            }
+
+            double costToGo = si_->distance(state, tempGoal);
+            double candidateCost = costToCome + costToGo;
+
+            // Make sure we improve before attempting validation
+            if (dists.back() - candidateCost > std::numeric_limits<float>::epsilon() &&
+                si_->checkMotion(state, tempGoal))
+            {
+                // insert the new states
+                if (startIndex == endIndex)
+                {
+                    // new intermediate state
+                    si_->copyState(states[startIndex], state);
+                    // new goal state
+                    si_->copyState(states[startIndex + 1], tempGoal);
+
+                    if (freeStates_)
+                    {
+                        for (size_t i = startIndex + 2; i < states.size(); ++i)
+                            si_->freeState(states[i]);
+                    }
+                    states.erase(states.begin() + startIndex + 2, states.end());
+                }
+                else
+                {
+                    // overwriting the end of the segment with the new state
+                    si_->copyState(states[endIndex], state);
+                    if (endIndex == states.size() - 1)
+                    {
+                        path.append(tempGoal);
+                    }
+                    else
+                    {
+                        // adding goal new goal state
+                        si_->copyState(states[endIndex + 1], tempGoal);
+                        if (freeStates_)
+                        {
+                            for (size_t i = endIndex + 2; i < states.size(); ++i)
+                                si_->freeState(states[i]);
+                        }
+                        states.erase(states.begin() + endIndex + 2, states.end());
+                    }
+                }
+
+                // fix the helper variables
+                dists.resize(states.size(), 0.0);
+                for (unsigned int j = std::max(1u, startIndex); j < dists.size(); ++j)
+                    dists[j] = dists[j - 1] + si_->distance(states[j - 1], states[j]);
+
+                betterGoal = true;
+            }
+        }
+    }
+
+    si_->freeState(temp);
+    si_->freeState(tempGoal);
+
+    return betterGoal;
+}
